@@ -35,4 +35,10 @@ class DescribeClientPackageRequest(RpcRequest):
 		return self.get_body_params().get('ClientType')
 
 	def set_ClientType(self,ClientType):
-		self.add_body_params('ClientType', ClientType)
\ No newline at end of file
+		self.add_body_params('ClientType', ClientType)
+
+	def get_ExtraParams(self):
+		return self.get_body_params().get('ExtraParams')
+
+	def set_ExtraParams(self,ExtraParams):
+		self.add_body_params('ExtraParams', ExtraParams)
\ No newline at end of file
